@@ -6,10 +6,14 @@ import pandas as pd
 import warnings
 
 from sklearn.base import BaseEstimator, TransformerMixin
+from sklearn.pipeline import Pipeline
 from sklearn.utils.validation import check_is_fitted
+
 from feature_engine.dataframe_checks import _is_dataframe, _check_input_matches_training_df, _check_contains_na
 from feature_engine.variable_manipulation import _find_categorical_variables, _define_variables
 from feature_engine.base_transformers import BaseCategoricalTransformer
+from feature_engine.discretisers import DecisionTreeDiscretiser
+
 
 
 def _check_encoding_dictionary(dictionary):
@@ -465,7 +469,8 @@ class WoERatioCategoricalEncoder(BaseCategoricalTransformer):
                 if self.encoding_method == 'log_ratio':
                     if not t.loc[t['p0'] == 0, :].empty or not t.loc[t['p1'] == 0, :].empty:
                         raise ValueError(
-                            "p(0) or p(1) for a category in variable {} is zero, log of zero is not defined".format(var))
+                            "p(0) or p(1) for a category in variable {} is zero, log of zero is not defined".format(
+                                var))
                     else:
                         self.encoder_dict_[var] = (np.log(t.p1 / t.p0)).to_dict()
 
@@ -701,11 +706,10 @@ class RareLabelCategoricalEncoder(BaseEstimator, TransformerMixin):
     replace_with : string, default='Rare'
         The category name that will be used to replace infrequent categories.
 
-    return_object: bool, default=False
-        Whether the variables should be re-cast as object, in case they have numerical values.
     """
 
-    def __init__(self, tol=0.05, n_categories=10, max_n_categories=None, variables=None, replace_with='Rare', return_object=False):
+
+    def __init__(self, tol=0.05, n_categories=10, max_n_categories=None, variables=None, replace_with='Rare'):
 
         if tol < 0 or tol > 1:
             raise ValueError("tol takes values between 0 and 1")
@@ -725,7 +729,6 @@ class RareLabelCategoricalEncoder(BaseEstimator, TransformerMixin):
         self.max_n_categories = max_n_categories
         self.variables = _define_variables(variables)
         self.replace_with = replace_with
-        self.return_object = return_object
 
     def fit(self, X, y=None):
         """
@@ -822,8 +825,156 @@ class RareLabelCategoricalEncoder(BaseEstimator, TransformerMixin):
         for feature in self.variables:
             X[feature] = np.where(X[feature].isin(self.encoder_dict_[feature]), X[feature], self.replace_with)
 
-        # add additional step to return variables cast as object
-        if self.return_object:
-            X[self.variables] = X[self.variables].astype('O')
+        return X
+
+
+class DecisionTreeCategoricalEncoder(BaseEstimator, TransformerMixin):
+    """
+    The DecisionTreeCategoricalEncoder() encodes categorical variables with predictions of a decision tree model.
+
+    The categorical variable will be first encoded into integers with the OrdinalCategoricalEncoder(). The
+    integers can be assigned arbitrarily to the categories or following the mean value of the target in each category.
+
+    Then a decision tree will be fit using the resulting numerical variable to predict the target  variable.
+    Finally, the original categorical variable values will be replaced by the predictions of the decision
+    tree.
+
+    Parameters
+    ----------
+
+    encoding_method: str, default='arbitrary'
+        The categorical encoding method that will be used to encode the original
+        categories to numerical values.
+
+        'ordered': the categories are numbered in ascending order according to
+        the target mean value per category.
+
+        'arbitrary' : categories are numbered arbitrarily.
+
+    cv : int, default=3
+        Desired number of cross-validation fold to be used to fit the decision
+        tree.
+        
+    scoring: str, default='neg_mean_squared_error'
+        Desired metric to optimise the performance for the tree. Comes from
+        sklearn metrics. See the DecisionTreeRegressor or DecisionTreeClassifier
+        model evaluation documentation for more options:
+        https://scikit-learn.org/stable/modules/model_evaluation.html
+    
+    regression : boolean, default=True
+        Indicates whether the encoder should train a regression or a classification
+        decision tree.
+        
+    param_grid : dictionary, default={'max_depth': [1,2,3,4]}
+        The list of parameters over which the decision tree should be optimised
+        during the grid search. The param_grid can contain any of the permitted
+        parameters for Scikit-learn's DecisionTreeRegressor() or
+        DecisionTreeClassifier().
+        
+    random_state : int, default=None
+        The random_state to initialise the training of the decision tree. It is one
+        of the parameters of the Scikit-learn's DecisionTreeRegressor() or
+        DecisionTreeClassifier(). For reproducibility it is recommended to set
+        the random_state to an integer.
+
+    variables : list, default=None
+        The list of categorical variables that will be encoded. If None, the
+        encoder will find and select all object type variables.
+
+    Attributes
+    ----------
+
+    encoder_ : sklearn Pipeline
+        Encoder pipeline containing the ordinal encoder and decision
+        tree discretiser.
+    """
+
+    def __init__(self, encoding_method='arbitrary', cv=3, scoring='neg_mean_squared_error',
+                 param_grid={'max_depth': [1, 2, 3, 4]}, regression=True,
+                 random_state=None, variables=None):
+      
+        self.encoding_method = encoding_method
+        self.cv = cv
+        self.scoring = scoring
+        self.regression = regression
+        self.param_grid = param_grid
+        self.random_state = random_state
+        self.variables = _define_variables(variables)
+
+    def fit(self, X, y=None):
+        """
+        Learns the numbers that should be used to replace the categories in each
+        variable.
+
+        Parameters
+        ----------
+
+        X : pandas dataframe of shape = [n_samples, n_features]
+            The training input samples.
+            Can be the entire dataframe, not just the categorical variables.
+
+        y : pandas series.
+            The target variable. Required to train the decision tree and for
+            ordered ordinal encoding.
+        """
+        # check input dataframe
+        X = _is_dataframe(X)
+
+        # find categorical variables or check that those entered by the user
+        # are of type object
+        self.variables = _find_categorical_variables(X, self.variables)
+
+        # check if dataset contains na
+        _check_contains_na(X, self.variables)
+
+        # initialize categorical encoder
+        cat_encoder = OrdinalCategoricalEncoder(encoding_method=self.encoding_method,
+                                                variables=self.variables)
+
+        # initialize decision tree discretiser
+        tree_discretiser = DecisionTreeDiscretiser(cv=self.cv, scoring=self.scoring,
+                                                   variables=self.variables, param_grid=self.param_grid,
+                                                   regression=self.regression, random_state=self.random_state)
+
+        # pipeline for the encoder
+        self.encoder_ = Pipeline([('categorical_encoder', cat_encoder),
+                                  ('tree_discretiser', tree_discretiser)])
+
+        self.encoder_.fit(X, y)
+
+        self.input_shape_ = X.shape
+
+        return self
+
+    def transform(self, X):
+        """
+        Returns the predictions of the decision tree based of the variable's original value.
+        
+        Parameters
+        ----------
+        
+        X : pandas dataframe of shape = [n_samples, n_features]
+            The input samples.
+        
+        Returns
+        -------
+        
+        X_transformed : pandas dataframe of shape = [n_samples, n_features].
+                        Dataframe with variables encoded with decision tree predictions.
+        """
+        # Check method fit has been called
+        check_is_fitted(self)
+
+        # check that input is a dataframe
+        X = _is_dataframe(X)
+
+        # check if dataset contains na
+        _check_contains_na(X, self.variables)
+
+        # Check that the dataframe contains the same number of columns than the dataframe
+        # used to fit the imputer.
+        _check_input_matches_training_df(X, self.input_shape_[1])
+
+        X = self.encoder_.transform(X)
 
         return X
